pub struct MemSummary {
pub first_message_id: Option<i64>,
pub last_message_id: Option<i64>,
pub content: String,
}Expand description
A conversation summary projection used by context assembly.
Fields
first_message_id: Option<i64>Row ID of the first message covered by this summary, if known.
last_message_id: Option<i64>Row ID of the last message covered by this summary, if known.
content: StringSummary text.