TaskSnapshot

Struct TaskSnapshot 

pub struct TaskSnapshot {
    pub name: Arc<str>,
    pub status: TaskStatus,
    pub started_at: Instant,
    pub restart_count: u32,
}
Point-in-time snapshot of a supervised task, returned by TaskSupervisor::snapshot. Observability surface per field:

Fieldtokio-consoleJaeger / OTLPTUImetrics histogram
namespan namespan nametask listlabel "task"
task.wall_time_msspan field (task-metrics)zeph.task.wall_time_ms
task.cpu_time_msspan field (task-metrics)zeph.task.cpu_time_ms
statustask list
restart_counttask list

The task.wall_time_ms and task.cpu_time_ms fields are only populated when the crate is compiled with the task-metrics feature.

Fields

name: Arc<str>

Task name.

status: TaskStatus

Current status.

started_at: Instant

Instant the task was first spawned.

restart_count: u32

Number of times the task has been restarted.