Shared audit signal types used by both the sanitizer and memory subsystems.
Defined here in zeph-common to eliminate the duplicate definitions that previously
existed in zeph-sanitizer::audit and zeph-memory::shadow. Both crates re-export
from this module.
Structs
- Audit
Signal - A single audit event emitted by a sanitizer subsystem.
Enums
- Audit
Signal Type - Signal type emitted by a sanitizer subsystem.
- Severity
- Severity level for an
AuditSignalType.